@@ -23,6 +23,9 @@
 #include "arraylist.h"
 #include "xsldbgmsg.h"
 #include "utils.h"
+#include <kglobal.h>
+#include <kstandarddirs.h> 
+#include <qfileinfo.h>
 
 
 /* keep track of our integer/boolean options */
@@ -81,6 +84,43 @@ const char *optionNames[] = {
     NULL                        /* indicate end of list */
 };
 
+
+
+// find the translated help documentation directory
+// langLookupDir code modified from langLookup function in kdebase/khelpcenter/view.cpp 
+
+static QString langLookupDir( const QString &fname )
+{
+    QStringList search;
+
+    // assemble the local search paths
+    const QStringList localDoc = KGlobal::dirs()->resourceDirs("html");
+
+    // look up the different languages
+    for (int id=localDoc.count()-1; id >= 0; --id)
+    {
+        QStringList langs = KGlobal::locale()->languageList();
+        langs.append( "en" );
+        langs.remove( "C" );
+        QStringList::ConstIterator lang;
+        for (lang = langs.begin(); lang != langs.end(); ++lang)
+            search.append(QString("%1%2/%3/%4").arg(localDoc[id]).arg(*lang).arg("xsldbg").arg(fname));
+    }
+
+    // try to locate the file
+    QStringList::Iterator it;
+    for (it = search.begin(); it != search.end(); ++it)
+    {
+	QString baseDir = (*it).left((*it).findRev('/')) ;
+	QFileInfo info(baseDir + "/"+ fname);
+	if (info.exists() && info.isFile() && info.isReadable())
+	  return baseDir;
+    }
+
+    return QString::null;
+}
+
+
 /** 
  * optionsInit:
  *
@@ -93,25 +133,6 @@ int
 optionsInit(void)
 {
     int optionId;
-    const xmlChar *docsPath = NULL;
-
-/* for non win32 environments see the macro in xsldebugger/Makefile.am
-   Win32 tupe systems see  macro in libxslt/xsltwin32config.h
-   For definition of USE_DOCS_MACRO see options.h */
-
-#ifdef USE_DOCS_MACRO
-#ifdef DOCS_PATH
-    docsPath = (xmlChar *) DOCS_PATH;
-#else
-#error	"DOCS_PATH not defined"
-#endif
-#else
-    docsPath = (xmlChar *) getenv(XSLDBG_DOCS_DIR_VARIABLE);
-    if (!docsPath) {
-        xsldbgGenericErrorFunc(i18n("Warning: No value for documentation specified in environment variable %1. No help nor search results will display.\n").arg((const char*)XSLDBG_DOCS_DIR_VARIABLE));
-    }
-#endif
-
 
     for (optionId = 0;
          optionId <= OPTIONS_LAST_INT_OPTIONID - OPTIONS_FIRST_INT_OPTIONID; optionId++) {
@@ -129,7 +150,7 @@ optionsInit(void)
     parameterList = arrayListNew(10, (freeItemFunc) optionsParamItemFree);
 
     /* setup the docs path */
-    optionsSetStringOption(OPTIONS_DOCS_PATH, docsPath);
+    optionsSetStringOption(OPTIONS_DOCS_PATH, (const xmlChar*)(langLookupDir("xsldbghelp.xml").utf8().data()));
 
     optionsSetIntOption(OPTIONS_TRACE, TRACE_OFF);
     optionsSetIntOption(OPTIONS_WALK_SPEED, WALKSPEED_STOP);
@@ -264,7 +285,7 @@ optionsSetIntOption(OptionTypeEnum optionType, int value)
         }
     } else {
 	if ((type >= OPTIONS_FIRST_OPTIONID) && (type <= OPTIONS_LAST_OPTIONID)){
-	     xsldbgGenericErrorFunc(i18n("Error: Option %1 is not a valid boolean/integer option.\n").arg((char*)optionNames[type - OPTIONS_FIRST_OPTIONID]));
+	     xsldbgGenericErrorFunc(i18n("Error: Option %1 is not a valid boolean/integer option.\n").arg(xsldbgText(optionNames[type - OPTIONS_FIRST_OPTIONID])));
 	}else{
 #ifdef WITH_XSLDBG_DEBUG_PROCESS
 	    xsldbgGenericErrorFunc(QString("Error: Invalid arguments for the command %1.\n").arg("setoption"));
@@ -294,7 +315,7 @@ optionsGetIntOption(OptionTypeEnum optionType)
         result = intOptions[type - OPTIONS_FIRST_INT_OPTIONID];
     } else {
 	if ((type >= OPTIONS_FIRST_OPTIONID) && (type <= OPTIONS_LAST_OPTIONID)){
-	    xsldbgGenericErrorFunc(i18n("Error: Option %1 is not a valid boolean/integer option.\n").arg((char*)optionNames[type - OPTIONS_FIRST_OPTIONID]));
+	    xsldbgGenericErrorFunc(i18n("Error: Option %1 is not a valid boolean/integer option.\n").arg(xsldbgText(optionNames[type - OPTIONS_FIRST_OPTIONID])));
 	}else{
 #ifdef WITH_XSLDBG_DEBUG_PROCESS
 	    xsldbgGenericErrorFunc(QString("Error: Invalid arguments for the command %1.\n").arg("options"));
@@ -336,7 +357,7 @@ optionsSetStringOption(OptionTypeEnum optionType, const xmlChar * value)
         result = 1;
     } else{
 	if ((type >= OPTIONS_FIRST_OPTIONID) && (type <= OPTIONS_LAST_OPTIONID)){
-	    xsldbgGenericErrorFunc(i18n("Error: Option %1 is not a valid string xsldbg option.\n").arg((char*)optionNames[type - OPTIONS_LAST_OPTIONID]));
+	    xsldbgGenericErrorFunc(i18n("Error: Option %1 is not a valid string xsldbg option.\n").arg(xsldbgText(optionNames[type - OPTIONS_LAST_OPTIONID])));
 	}else{
 #ifdef WITH_XSLDBG_DEBUG_PROCESS
 	    xsldbgGenericErrorFunc(QString("Error: Invalid arguments for the command %1.\n").arg("setoption"));
@@ -367,7 +388,7 @@ optionsGetStringOption(OptionTypeEnum optionType)
         result = stringOptions[optionId];
     } else{
 	if ((type >= OPTIONS_FIRST_OPTIONID) && (type <= OPTIONS_LAST_OPTIONID)){
-	    xsldbgGenericErrorFunc(i18n("Error: Option %1 is not a valid string xsldbg option.\n").arg((char*)optionNames[type - OPTIONS_FIRST_OPTIONID]));
+	    xsldbgGenericErrorFunc(i18n("Error: Option %1 is not a valid string xsldbg option.\n").arg(xsldbgText(optionNames[type - OPTIONS_FIRST_OPTIONID])));
 	}else{
 #ifdef WITH_XSLDBG_DEBUG_PROCESS
 	    xsldbgGenericErrorFunc(QString("Error: Invalid arguments for the command %1.\n").arg("options"));
@@ -479,7 +500,7 @@ optionsPrintParam(int paramId)
                                         paramId);
 
     if (paramItem && paramItem->name && paramItem->value) {
-        xsldbgGenericErrorFunc(i18n(" Parameter %1 %2=\"%3\"\n").arg(paramId).arg((char*)paramItem->name).arg((char*)paramItem->value));
+        xsldbgGenericErrorFunc(i18n(" Parameter %1 %2=\"%3\"\n").arg(paramId).arg(xsldbgText(paramItem->name)).arg(xsldbgText(paramItem->value)));
         result = 1;
     }
     return result;
