@@ -53,18 +53,15 @@
 #include <kpopupmenu.h>
 #include <kprocess.h>
 #include <kprogress.h>
-#include <kspell.h>
 #include <ktip.h>
 #include <kio/netaccess.h>
 #include <ktabwidget.h>
 #include <kmultitabbar.h>
 
-#ifdef BUILD_KAFKAPART
 #include "wkafkapart.h"
 #include "kafkacommon.h"
 #include "undoredo.h"
 #include <dom/dom_string.h>
-#endif
 
 // application specific includes
 
@@ -108,8 +105,12 @@
 #include "dirtydialog.h"
 
 #include "dtds.h"
-#include "spellchecker.h"
 #include "qpevents.h"
+#include "quantabookmarks.h"
+
+#include "tagactionmanager.h"
+#include "tagactionset.h"
+
 
 QuantaInit::QuantaInit(QuantaApp * quantaApp)
         : QObject()
@@ -152,6 +153,7 @@ void QuantaInit::initQuanta()
   qConfig.defaultDocType = m_config->readEntry("Default DTD",DEFAULT_DTD);
   if (! DTDs::ref()->find(qConfig.defaultDocType))
      qConfig.defaultDocType = DEFAULT_DTD;
+  DTDs::ref()->find("dtd"); //load on startup
 
   initView();
   initDocument();  // after initView because of init of treeViews
@@ -185,6 +187,7 @@ void QuantaInit::initQuanta()
   m_quanta->m_messageOutputView = addToolTreeView(m_quanta->m_messageOutput, i18n("Messages"), SmallIcon("openterm"), KDockWidget::DockBottom);
   m_quanta->m_problemsOutputView = addToolTreeView(m_quanta->m_problemOutput, i18n("Problems"), SmallIcon("info"), KDockWidget::DockBottom);
 
+  // Restore the dock layout
   m_config->setGroup  ("General Options");
   QString layout = m_config->readEntry("Window layout", "Default");
   int mdiMode = m_config->readNumEntry("MDI mode", -1);
@@ -194,6 +197,7 @@ void QuantaInit::initQuanta()
       if (mdiMode != KMdi::IDEAlMode)
         m_quanta->setToolviewStyle(qConfig.toolviewTabs);
   }
+  
   m_quanta->initTabWidget(true);
   qConfig.windowLayout = "Custom";
   //FIXME: This is a hack to workaround the starting problem when we are in Toplevel mode.
@@ -266,6 +270,7 @@ void QuantaInit::initQuanta()
   m_quanta->slotFileNew();
   m_quanta->slotNewStatus();
   initToolBars();
+  Project::ref()->setProjectToolbarVisible(m_quanta->factory()->container("project_toolbar", m_quanta)->isShown());
   Project::ref()->slotShowProjectToolbar(Project::ref()->hasProject());
   KTipDialog::showTip(m_quanta);
 
@@ -302,8 +307,8 @@ void QuantaInit::initQuanta()
 
 void QuantaInit::initToolBars()
 {
- if (m_quanta->toolbarList.count() == 0)
-     m_quanta->loadToolbarForDTD(Project::ref()->defaultDTD());
+ if (m_quanta->m_toolbarList.count() == 0)
+   m_quanta->slotLoadToolbarForDTD(Project::ref()->defaultDTD());
 }
 
 void QuantaInit::initStatusBar()
@@ -314,10 +319,11 @@ void QuantaInit::initStatusBar()
 
   progressBar = new KProgress(m_quanta->statusBar());
   progressBar->setTextEnabled(false);
+  progressBar->setMaximumHeight(progressBar->fontMetrics().height());
   progressBar->show();
   m_quanta->statusBar()->insertItem(i18n(IDS_DEFAULT),IDS_STATUS, 1);
   m_quanta->statusBar()->addWidget(progressBar);
-  m_quanta->statusBar()->insertFixedItem(" XXX ",     IDS_INS_OVR  );
+  m_quanta->statusBar()->insertItem("",               IDS_INS_OVR  );
   m_quanta->statusBar()->insertFixedItem(" * ",       IDS_MODIFIED );
   m_quanta->statusBar()->insertFixedItem(i18n("Line: 00000 Col: 000"), IDS_STATUS_CLM, true);
 
@@ -369,6 +375,7 @@ void QuantaInit::initProject()
           m_project, SLOT(slotInsertFile(const KURL&)));
   connect(TemplatesTreeView::ref(), SIGNAL(downloadTemplate()),
           m_quanta, SLOT(slotDownloadTemplate()));
+  connect(TemplatesTreeView::ref(), SIGNAL(uploadTemplate(const QString&)), m_quanta, SLOT(slotUploadTemplate(const QString&)));
 
   // inform project if something was renamed
   connect(pTab, SIGNAL(renamed(const KURL&, const KURL&)),
@@ -382,8 +389,8 @@ void QuantaInit::initProject()
           m_project, SLOT(slotInsertFile(const KURL&)));
   connect(pTab, SIGNAL(removeFromProject(const KURL&)),
           m_project, SLOT(slotRemove(const KURL&)));
-  connect(pTab, SIGNAL(uploadSingleURL(const KURL&)),
-          m_project, SLOT(slotUploadURL(const KURL&)));
+  connect(pTab, SIGNAL(uploadSingleURL(const KURL&, bool)),
+          m_project, SLOT(slotUploadURL(const KURL&, bool)));
   connect(pTab, SIGNAL(rescanProjectDir()), m_project, SLOT(slotRescanPrjDir()));
   connect(pTab, SIGNAL(showProjectOptions()), m_project, SLOT(slotOptions()));
   connect(pTab, SIGNAL(uploadProject()), m_project, SLOT(slotUpload()));
@@ -429,12 +436,10 @@ void QuantaInit::initView()
   connect(m_quanta, SIGNAL(viewActivated (KMdiChildView *)), m_viewManager, SLOT(slotViewActivated(KMdiChildView*)));
   connect(m_quanta, SIGNAL(lastChildViewClosed()), m_viewManager, SLOT(slotLastViewClosed()));
 //   connect(m_quanta, SIGNAL(viewDeactivated(KMdiChildView *)), m_viewManager, SLOT(slotViewDeactivated(KMdiChildView*)));
-#ifdef BUILD_KAFKAPART
    KafkaDocument *m_kafkaDocument = KafkaDocument::ref(0, 0, "KafkaPart");
    m_kafkaDocument->getKafkaWidget()->view()->setMinimumHeight(50);
    m_kafkaDocument->readConfig(quantaApp->config());
    loadVPLConfig();
-#endif
   (void) ToolbarTabWidget::ref(quantaApp);
   //set the toolview and close button style before the GUI is created
   m_config->setGroup  ("General Options");
@@ -489,6 +494,8 @@ void QuantaInit::initView()
   connect(m_quanta->scriptTab, SIGNAL(assignActionToScript(const KURL &, const QString&)),
           m_quanta, SLOT(slotAssignActionToScript(const KURL &, const QString&)));
   connect(m_quanta->scriptTab, SIGNAL(downloadScript()), m_quanta, SLOT(slotDownloadScript()));
+  connect(m_quanta->scriptTab, SIGNAL(uploadScript(const QString&)), m_quanta, SLOT(slotUploadScript(const QString&)));
+  connect(m_quanta->dTab, SIGNAL(downloadDoc()), m_quanta, SLOT(slotDownloadDoc()));
 
   connect(m_quanta->m_htmlPart, SIGNAL(onURL(const QString&)),
               m_quanta, SLOT(slotStatusMsg(const QString&)));
@@ -499,11 +506,15 @@ void QuantaInit::initView()
   connect(sTab, SIGNAL(selectArea(int,int,int,int)), m_quanta, SLOT( selectArea(int,int,int,int)));
   connect(sTab, SIGNAL(selectTagArea(Node*)), m_quanta, SLOT(slotSelectTagArea(Node*)));
   connect(sTab, SIGNAL(needReparse()), m_quanta, SLOT(slotForceReparse()));
-  connect(sTab, SIGNAL(parsingDTDChanged(const QString&)), m_quanta, SLOT(slotParsingDTDChanged(const QString&)));
+  connect(sTab, SIGNAL(showGroupsForDTEP(const QString&, bool)), m_quanta, SLOT(slotShowGroupsForDTEP(const QString&, bool)));
   connect(sTab, SIGNAL(openFile(const KURL &)),
           m_quanta, SLOT  (slotFileOpen(const KURL &)));
   connect(sTab, SIGNAL(openImage  (const KURL&)),
           m_quanta, SLOT(slotImageOpen(const KURL&)));
+  connect(sTab, SIGNAL(showProblemMessage(const QString&)),
+          m_quanta->m_problemOutput, SLOT(showMessage(const QString&)));
+  connect(sTab, SIGNAL(clearProblemOutput()),
+          m_quanta->m_problemOutput, SLOT(clear()));
   connect(parser, SIGNAL(nodeTreeChanged()), sTab, SLOT(slotNodeTreeChanged()));
 
   connect(m_quanta->dTab, SIGNAL(openURL(const QString&)), m_quanta, SLOT(openDoc(const QString&)));
@@ -515,9 +526,9 @@ void QuantaInit::initView()
 
 KMdiToolViewAccessor* QuantaInit::addToolTreeView(QWidget *widget, const QString &name, const QPixmap &icon, KDockWidget::DockPosition position)
 {
-   widget->setIcon(icon);
-   widget->setCaption(name);
-   return m_quanta->addToolWindow(widget, position, m_quanta->getMainDockWidget());
+  widget->setIcon(icon);
+  widget->setCaption(name);
+  return m_quanta->addToolWindow(widget, m_quanta->prevDockPosition(widget, position), m_quanta->getMainDockWidget());
 }
 
 void QuantaInit::readOptions()
@@ -571,9 +582,9 @@ void QuantaInit::readOptions()
 
   m_quanta->m_previewVisible = false;
   m_quanta->m_noFramesPreview = false;
-#ifdef BUILD_KAFKAPART
-  m_quanta->showKafkaAction->setChecked( false );
-#endif
+
+  m_quanta->showVPLAction->setChecked( false );
+
 
 //KNewStuff config
    m_config->setGroup("KNewStuff");
@@ -586,7 +597,6 @@ void QuantaInit::readOptions()
 
 
   Project::ref()->readConfig(m_config); // project
-  SpellChecker::ref()->readConfig(m_config);
 }
 
 void QuantaInit::openLastFiles()
@@ -676,10 +686,7 @@ void QuantaInit::initActions()
     KStdAction::cut(m_quanta, SLOT(slotCut()), ac);
     KStdAction::copy(m_quanta, SLOT(slotCopy()), ac) ;
     KStdAction::pasteText(m_quanta, SLOT(slotPaste()), ac);
-
-//Tools menu
-    KStdAction::spelling(m_quanta, SLOT(slotSpellcheck()), ac);
-
+    
 //help
    (void) new KAction(i18n("Ti&p of the Day"), "idea", "", m_quanta,
       SLOT(slotHelpTip()), ac, "help_tip");
@@ -708,7 +715,7 @@ void QuantaInit::initActions()
     m_quanta->saveAllAction = new KAction( i18n( "Save All..." ), "save_all", SHIFT+KStdAccel::shortcut(KStdAccel::Save).keyCodeQt(),
                         m_quanta, SLOT( slotFileSaveAll() ),
                         ac, "file_save_all" );
-    (void)  new KAction(i18n("Reloa&d"), "revert", CTRL+Key_F5, m_quanta,
+    (void)  new KAction(i18n("Reloa&d"), "revert", SHIFT+Key_F5, m_quanta,
                         SLOT(slotFileReload()), ac, "file_reload");
 //    (void)  new KAction(i18n("Reload All "), 0, 0, m_quanta,
 //                        SLOT(slotFileReloadAll()), ac, "file_reload_all");
@@ -729,7 +736,11 @@ void QuantaInit::initActions()
                         SmallIcon("filefind"), CTRL+ALT+Key_F,
                         m_quanta, SLOT( slotEditFindInFiles() ),
                         ac, "find_in_files" );
-
+    
+    KAction* aux = TagActionManager::self()->actionCollection()->action("apply_source_indentation");
+    aux->setEnabled(false);
+    ac->insert(aux);
+    
     // Tool actions
 
     (void) new KAction( i18n( "&Context Help..." ), CTRL+Key_H,
@@ -755,6 +766,10 @@ void QuantaInit::initActions()
     (void) new KAction( i18n( "&Change the DTD..." ), 0,
                         m_quanta, SLOT( slotChangeDTD() ),
                         ac, "change_dtd" );
+    
+    (void) new KAction( i18n( "&Edit DTD Settings..." ), 0,
+    m_quanta, SLOT( slotEditDTD() ),
+    ac, "edit_dtd" );
 
     (void) new KAction( i18n( "&Load && Convert DTD..." ), 0,
                         DTDs::ref(), SLOT( slotLoadDTD() ),
@@ -771,42 +786,46 @@ void QuantaInit::initActions()
     (void) new KAction( i18n( "&Download DTD Package (DTEP)..." ), "network", 0,
                         m_quanta, SLOT( slotDownloadDTEP() ),
                         ac, "download_dtep" );
+    (void) new KAction( i18n( "&Upload DTD Package (DTEP)..." ), "network", 0,
+                        m_quanta, SLOT( slotUploadDTEP() ),
+                        ac, "upload_dtep" );
 /*
     (void) new KAction( i18n( "&Upload DTD Package (DTEP)..." ), 0,
                         m_quanta, SLOT( slotUploadDTEP() ),
                         ac, "send_dtep" );
 */
-#ifdef BUILD_KAFKAPART
     (void) new KAction( i18n( "&Document Properties" ), 0,
                         m_quanta, SLOT( slotDocumentProperties() ),
                         ac, "tools_document_properties" );
-#endif
 
+/*    (void) new KAction ( i18n ("F&ormat XML Code"), 0,
+                        m_quanta, SLOT( slotCodeFormatting() ),
+                        ac, "tools_code_formatting");
+*/
     (void) new KAction( i18n( "&Convert Tag && Attribute Case..."), 0,
                         m_quanta, SLOT(slotConvertCase()),
                         ac, "tools_change_case");
 
     // View actions
 
-#ifdef BUILD_KAFKAPART
-    KToggleAction *ta;
-      ta =
+
+    m_quanta->showSourceAction =
       new KToggleAction( i18n( "&Source Editor"), UserIcon ("view_text"), ALT+Key_F9,
                          m_quanta, SLOT( slotShowSourceEditor()),
                          ac, "show_quanta_editor");
-      ta->setExclusiveGroup("view");
+    m_quanta->showSourceAction->setExclusiveGroup("view");
 
-     m_quanta->showKafkaAction =
+    m_quanta->showVPLAction =
       new KToggleAction( i18n( "&VPL Editor"), UserIcon ("vpl"), CTRL+SHIFT+Key_F9,
       m_quanta, SLOT( slotShowVPLOnly() ),
                           ac, "show_kafka_view");
-     m_quanta->showKafkaAction->setExclusiveGroup("view");
+    m_quanta->showVPLAction->setExclusiveGroup("view");
 
-     ta =
+    m_quanta->showVPLSourceAction =
       new KToggleAction( i18n("VPL && So&urce Editors"), UserIcon ("vpl_text"), Key_F9,
                          m_quanta, SLOT( slotShowVPLAndSourceEditor() ),
                           ac, "show_kafka_and_quanta");
-     ta->setExclusiveGroup("view");
+    m_quanta->showVPLSourceAction->setExclusiveGroup("view");
     /**kafkaSelectAction = new KSelectAction(i18n("Main &View"), 0, ac,"show_kafka");
     QStringList list2;
     list2.append(i18n("&Source Editor"));
@@ -814,7 +833,7 @@ void QuantaInit::initActions()
     list2.append(i18n("&Both Editors"));
     kafkaSelectAction->setItems(list2);
     connect(kafkaSelectAction, SIGNAL(activated(int)), m_quanta, SLOT(slotShowKafkaPartl(int)));*/
-#endif
+
 
     (void) new KAction( i18n( "&Reload Preview" ), "reload",
                         KStdAccel::shortcut(KStdAccel::Reload).keyCodeQt(),
@@ -850,16 +869,15 @@ void QuantaInit::initActions()
     new KAction(i18n("Load &Local Toolbar..."), 0, m_quanta, SLOT(slotLoadToolbar()), ac, "toolbars_load_user");
     new KAction(i18n("Save as &Local Toolbar..."), 0, m_quanta, SLOT(slotSaveLocalToolbar()), ac, "toolbars_save_local");
     new KAction(i18n("Save as &Project Toolbar..."), 0, m_quanta, SLOT(slotSaveProjectToolbar()), ac, "toolbars_save_project");
-    new KAction(i18n("&Add User Toolbar..."),  0, m_quanta, SLOT(slotAddToolbar()), ac, "toolbars_add");
+    new KAction(i18n("&New User Toolbar..."),  0, m_quanta, SLOT(slotAddToolbar()), ac, "toolbars_add");
     new KAction(i18n("&Remove User Toolbar..."), 0, m_quanta, SLOT(slotRemoveToolbar()), ac, "toolbars_remove");
     new KAction(i18n("Re&name User Toolbar..."), 0, m_quanta, SLOT(slotRenameToolbar()), ac, "toolbars_rename");
     new KAction(i18n("Send Toolbar in E&mail..."), "mail_send", 0, m_quanta, SLOT(slotSendToolbar()), ac, "toolbars_send");
+    new KAction(i18n("&Upload Toolbar..." ), "network", 0, m_quanta, SLOT(slotUploadToolbar()), ac, "toolbars_upload" );
     new KAction(i18n("&Download Toolbar..." ), "network", 0, m_quanta, SLOT(slotDownloadToolbar()), ac, "toolbars_download" );
 
-#ifdef BUILD_KAFKAPART
     KToggleAction *toggle = new KToggleAction( i18n("Smart Tag Insertion"), 0, ac, "smart_tag_insertion");
     connect(toggle, SIGNAL(toggled(bool)), m_quanta, SLOT(slotSmartTagInsertion()));
-#endif
 
     m_quanta->showDTDToolbar=new KToggleAction(i18n("Show DTD Toolbar"), 0, ac, "view_dtd_toolbar");
 
@@ -947,8 +965,8 @@ void QuantaInit::initActions()
                                   m_quanta, SLOT(slotShowNoFramesPreview()),
                                   ac, "show_preview_no_frames" );
     act->plug(m_quanta->showPreviewAction->popupMenu());
-
-    act = new KAction( i18n( "View with &Konqueror" ), "konqueror", CTRL+Key_F6,
+    
+    act = new KAction( i18n( "View with &Konqueror" ), "konqueror", Key_F12,
                         m_quanta, SLOT( slotViewInKFM() ),
                         ac, "view_with_konqueror" );
     act->plug(m_quanta->showPreviewAction->popupMenu());
@@ -965,7 +983,7 @@ void QuantaInit::initActions()
     if (act)
       act->plug(m_quanta->showPreviewAction->popupMenu());
 
-    act = new KAction( i18n( "View with L&ynx" ), "terminal", SHIFT+Key_F6,
+    act = new KAction( i18n( "View with L&ynx" ), "terminal", 0,
                         m_quanta, SLOT( slotViewInLynx() ),
                         ac, "view_with_lynx" );
     act->plug(m_quanta->showPreviewAction->popupMenu());
@@ -1018,6 +1036,10 @@ void QuantaInit::initActions()
     connect(m_quanta, SIGNAL(eventHappened(const QString&, const QString&, const QString& )), QPEvents::ref(m_quanta), SLOT(slotEventHappened(const QString&, const QString&, const QString& )));
     connect(m_quanta->doc(), SIGNAL(eventHappened(const QString&, const QString&, const QString& )), QPEvents::ref(m_quanta), SLOT(slotEventHappened(const QString&, const QString&, const QString& )));
     connect(ViewManager::ref(), SIGNAL(eventHappened(const QString&, const QString&, const QString& )), QPEvents::ref(m_quanta), SLOT(slotEventHappened(const QString&, const QString&, const QString& )));
+
+    QuantaBookmarks *m_bookmarks = new QuantaBookmarks(ViewManager::ref(m_quanta));
+    m_bookmarks->createActions(ac);
+    connect(m_bookmarks, SIGNAL(gotoFileAndLine(const QString&, int, int)), m_quanta, SLOT(gotoFileAndLine(const QString&, int, int)));
 }
 
 /** Initialize the plugin architecture. */
@@ -1171,20 +1193,20 @@ void QuantaInit::recoverCrashed(QStringList& recoveredFileNameList)
 
   //We create a KProcess that executes the "ps" *nix command to get the PIDs of the
   //other instances of quanta actually running
-  m_quanta->m_execCommandPS = new KProcess();
-  *(m_quanta->m_execCommandPS) << QStringList::split(" ",cmd);
+  KProcess *execCommand = new KProcess();
+  *(execCommand) << QStringList::split(" ",cmd);
 
-  connect( m_quanta->m_execCommandPS, SIGNAL(receivedStdout(KProcess*,char*,int)),
-           m_quanta, SLOT(slotGetScriptOutput(KProcess*,char*,int)));
-  connect( m_quanta->m_execCommandPS, SIGNAL(receivedStderr(KProcess*,char*,int)),
-           m_quanta, SLOT(slotGetScriptError(KProcess*,char*,int)));
-  connect( m_quanta->m_execCommandPS, SIGNAL(processExited(KProcess*)),
-           m_quanta, SLOT(slotProcessExited(KProcess*)));
+  connect(execCommand, SIGNAL(receivedStdout(KProcess*,char*,int)),
+          m_quanta, SLOT(slotGetScriptOutput(KProcess*,char*,int)));
+  connect(execCommand, SIGNAL(receivedStderr(KProcess*,char*,int)),
+          m_quanta, SLOT(slotGetScriptError(KProcess*,char*,int)));
+  connect(execCommand, SIGNAL(processExited(KProcess*)),
+          m_quanta, SLOT(slotProcessExited(KProcess*)));
 
-  //if KProcess fails I think a message box is needed... I will fix it
-  if (!m_quanta->m_execCommandPS->start(KProcess::NotifyOnExit,KProcess::All))
-    kdError() << "Failed to query for running Quanta instances!" << endl;
-    //TODO: Replace the above error with a real messagebox after the message freeze is over
+  if (!execCommand->start(KProcess::NotifyOnExit,KProcess::All))
+  {
+    KMessageBox::error(m_quanta, i18n("Failed to query for running Quanta instances."));
+  }
   else
   {
     //To avoid lock-ups, start a timer.
@@ -1260,7 +1282,6 @@ QString QuantaInit::retrieveBaseFileName(const QString& filename)
 
 void QuantaInit::loadVPLConfig()
 {
-#ifdef BUILD_KAFKAPART
   //load the VPL options
   m_config->setGroup("Kafka Synchronization options");
   qConfig.quantaRefreshOnFocus = (m_config->readEntry("Source refresh", "delay") == "focus");
@@ -1268,28 +1289,119 @@ void QuantaInit::loadVPLConfig()
   qConfig.kafkaRefreshOnFocus = (m_config->readEntry("Kafka refresh", "focus") == "focus");
   qConfig.kafkaRefreshDelay = m_config->readNumEntry("Kafka refresh delay", 4000);
   /**reloadUpdateTimers();*/
-#endif
+
+  m_config->setGroup("Kafka Indentation options");  
+  qConfig.inlineNodeIndentation = m_config->readBoolEntry("Inline Node Indentation");
 }
 
+struct Dependency{
+  QString name;
+  QString execName;
+  QString url;
+  QString description;
+  enum Type{
+    Executable = 0,
+    Plugin
+  };
+  Type type;
+};
+  
 void QuantaInit::checkRuntimeDependencies()
 {
-  QString stdErrorMsg = i18n("<br><b>-    %1</b> [<i>%2</i>] - %3 will not be available;");
+  
+  QValueList<Dependency> dependencies;
+  Dependency dependency;
+  dependency.name = "Kommander";
+  dependency.execName = "kmdr-executor";
+  dependency.url = "http://kommander.kdewebdev.org";
+  dependency.description = i18n("various script based dialogs including the Quick Start dialog");
+  dependency.type = Dependency::Executable;
+  dependencies.append(dependency);
+  
+  dependency.name = "Tidy";
+  dependency.execName = "tidy";
+  dependency.url = "http://tidy.sourceforge.net";
+  dependency.description = i18n("HTML syntax checking");
+  dependency.type = Dependency::Executable;
+  dependencies.append(dependency);
+  
+  dependency.name = "Kompare";
+  dependency.execName = "kompare";
+  dependency.url = "http://bruggie.dnsalias.org/kompare";
+  dependency.description = i18n("comparing of files by content");
+  dependency.type = Dependency::Executable;
+  dependencies.append(dependency);
+  
+    
+  dependency.name = i18n("Control Center (kdebase)");
+  dependency.execName = "kcmshell";
+  dependency.url = "http://www.kde.org";
+  dependency.description = i18n("preview browser configuration");
+  dependency.type = Dependency::Executable;
+  dependencies.append(dependency);
+  
+  dependency.name = "GPG (OpenPGP)";
+  dependency.execName = "gpg";
+  dependency.url = "http://www.gnupg.de";
+  dependency.description = i18n("preview browser configuration");
+  dependency.type = Dependency::Executable;
+  dependencies.append(dependency);
+  
+  dependency.name = "KFileReplace)";
+  dependency.execName = "KFileReplace";
+  dependency.url = "http://kfilereplace.kdewebdev.org";
+  dependency.description = i18n("search and replace in files");
+  dependency.type = Dependency::Plugin;
+  dependencies.append(dependency);
+  
+  dependency.name = "KXSLDbg";
+  dependency.execName = "XSLT Debugger";
+  dependency.url = "http://xsldbg.sourceforge.net/";
+  dependency.description = i18n("XSLT debugging");
+  dependency.type = Dependency::Plugin;
+  dependencies.append(dependency);
+  
+    
+  dependency.name = "KImageMapEditor";
+  dependency.execName = "KImageMapEditor";
+  dependency.url = "http://www.nongnu.org/kimagemap/";
+  dependency.description = i18n("editing HTML image maps");
+  dependency.type = Dependency::Plugin;
+  dependencies.append(dependency);
+  
+    
+  dependency.name = "KLinkStatus";
+  dependency.execName = "Link Checker";
+  dependency.url = "http://kde-apps.org/content/show.php?content=12318";
+  dependency.description = i18n("link validity checking");
+  dependency.type = Dependency::Plugin;
+  dependencies.append(dependency);
+  
+  dependency.name = "Cervisia";
+  dependency.execName = "CVS Management (Cervisia)";
+  dependency.url = "http://www.kde.org/apps/cervisia";
+  dependency.description = i18n("CVS management plugin");
+  dependency.type = Dependency::Plugin;
+  dependencies.append(dependency);
+  
   QString errorStr;
-  if (KStandardDirs::findExe("kmdr-executor").isNull())
-    errorStr += QString(stdErrorMsg).arg(i18n("Kommander")).arg("http://kommander.kdewebdev.org").arg(i18n("various script based dialogs including the Quick Start dialog"));
-  if (KStandardDirs::findExe("tidy").isNull())
-    errorStr += QString(stdErrorMsg).arg("Tidy").arg("http://tidy.sourceforge.net").arg(i18n("HTML syntax checking"));
-  if (KStandardDirs::findExe("kompare").isNull())
-    errorStr += QString(stdErrorMsg).arg("Kompare").arg("http://bruggie.dnsalias.org/kompare").arg(i18n("comparing of files by content"));
-  if (KStandardDirs::findExe("kcmshell").isNull())
-    errorStr += QString(stdErrorMsg).arg("KControl (kdebase)").arg("http://www.kde.org").arg(i18n("preview browser configuration"));
-  if (KStandardDirs::findExe("gpg").isNull())
-    errorStr += QString(stdErrorMsg).arg("GPG (OpenPGP)").arg("http://www.gnupg.de").arg(i18n("resource signing and validating"));
-  if (!QuantaPlugin::validatePlugin(m_quanta->m_pluginInterface->plugin("KFileReplace")))
-    errorStr += QString(stdErrorMsg).arg("KFileReplace").arg("http://kfilereplace.kdewebdev.org").arg(i18n("search and replace in files"));
-  if (!QuantaPlugin::validatePlugin(m_quanta->m_pluginInterface->plugin("CVS Management (Cervisia)")))
-    errorStr += QString(stdErrorMsg).arg("Cervisia").arg("http://www.kde.org/apps/cervisia").arg(i18n("CVS management plugin"));
-
+  QString stdErrorMsg = i18n("<br><b>-    %1</b> [<i>%2</i>] - %3 will not be available;");
+  for (QValueList<Dependency>::ConstIterator it = dependencies.constBegin(); it != dependencies.constEnd(); ++it)
+  {
+    dependency = *it;
+    if (dependency.type == Dependency::Executable)
+    {
+      if (KStandardDirs::findExe(dependency.execName).isNull())
+        errorStr += QString(stdErrorMsg).arg(dependency.name).arg(dependency.url).arg(dependency.description);
+    
+    } else
+    if (dependency.type == Dependency::Plugin)
+    {
+      if (!QuantaPlugin::validatePlugin(m_quanta->m_pluginInterface->plugin(dependency.execName)))
+        errorStr += QString(stdErrorMsg).arg(dependency.name).arg(dependency.url).arg(dependency.description);
+    }
+  }
+  
 #ifdef ENABLE_CVSSERVICE
   QString error;
   QCString appId;
