@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 // QT includes
+#include <qeventloop.h>
 #include <qlayout.h>
 #include <qfileinfo.h>
 #include <qlabel.h>
@@ -31,8 +32,10 @@
 #include <qptrstack.h>
 
 // KDE includes
+#include <kaction.h>
 #include <kdebug.h>
 #include <krun.h>
+#include <kinputdialog.h>
 #include <klocale.h>
 #include <kiconloader.h>
 #include <kopenwith.h>
@@ -45,6 +48,7 @@
 #include <kurl.h>
 #include <ktar.h>
 #include <ktempfile.h>
+#include <ktrader.h>
 #include <kapplication.h>
 #include <kcursor.h>
 #include <kprotocolinfo.h>
@@ -287,7 +291,7 @@ void BaseTreeBranch::updateOpenFolder()
   while (item) {
     if (item->isDir() && item->isOpen()) {
       updateDirectory( item->url() );
-      kapp->processEvents();
+      kapp->processEvents(QEventLoop::ExcludeUserInput | QEventLoop::ExcludeSocketNotifiers);
       // dive into the tree first
       newItem = dynamic_cast<KFileTreeViewItem *>(item->firstChild());
       if (newItem) {
@@ -314,7 +318,7 @@ void BaseTreeBranch::updateOpenFolder()
 ////////////////////////////////////////////////////////////////////////////////////
 
 BaseTreeView::BaseTreeView(QWidget *parent, const char *name)
-: KFileTreeView(parent, name), fileInfoDlg(0), m_saveOpenFolder(false)
+: KFileTreeView(parent, name), fileInfoDlg(0), m_saveOpenFolder(false), m_openWithMenu(0L), m_openWithMenuId(-1)
 {
   m_parent = parent;
   QToolTip::remove(viewport());  // remove the tooltip from QListView
@@ -571,6 +575,48 @@ void BaseTreeView::slotOpenWith()
   }
 }
 
+void BaseTreeView::slotOpenWithApplication()
+{
+  KService::Ptr ptr = KService::serviceByDesktopPath(sender()->name());
+  if (ptr)
+  {
+    KURL::List list;
+    list << currentURL();
+    KRun::run(*ptr, list);
+  }
+}
+
+void BaseTreeView::insertOpenWithMenu(KPopupMenu *menu, int position)
+{
+  if (m_openWithMenuId != -1)
+    menu->removeItem(m_openWithMenuId);
+  for (uint i = 0; i < m_openWithActions.count(); i++)
+  {
+    KAction *action = m_openWithActions[i];
+    delete action;
+  }
+  m_openWithActions.clear();
+  KURL urlToOpen = currentURL();
+  QString mimeType = KMimeType::findByURL(urlToOpen, 0, true, true)->name();
+  KTrader::OfferList offers = KTrader::self()->query(mimeType, "Type == 'Application'");
+
+  if (offers.count() > 0)
+  {
+    m_openWithMenu = new KPopupMenu(this);
+    KTrader::OfferList::Iterator it;
+    for (it = offers.begin(); it != offers.end(); ++it)
+    {
+      KAction *action = new KAction((*it)->name(), (*it)->icon(), 0, 0, QFile::encodeName((*it)->desktopEntryPath()).data());
+      connect(action, SIGNAL(activated()), this, SLOT(slotOpenWithApplication()));
+      action->plug(m_openWithMenu);
+      m_openWithActions.append(action);
+    }
+    m_openWithMenu->insertSeparator();
+    m_openWithMenu->insertItem(i18n("&Other..."), this, SLOT(slotOpenWith()));
+    m_openWithMenuId = menu->insertItem(i18n("Open &With"), m_openWithMenu, -1, position);
+  } else
+    m_openWithMenuId = menu->insertItem(i18n("Open &With..."), this, SLOT(slotOpenWith()), 0, -1, position);
+}
 
 void BaseTreeView::slotInsertTag()
 {
@@ -1018,7 +1064,7 @@ void BaseTreeView::saveLayout(KConfig *config, const QString &group)
       // remember the root url so that I find the branch on restore
       folderList.append(btb->rootUrl().url());
       btb->addOpenFolder(&folderList);
-      config->writeEntry("OpenFolderList" + QString::number(i), folderList);
+      config->writePathEntry("OpenFolderList" + QString::number(i), folderList);
     }
   }
   config->writeEntry("NumOpenFolderList", i);
@@ -1130,4 +1176,46 @@ void BaseTreeView::slotCreateSiteTemplate()
    delete tempFile;
 }
 
+void BaseTreeView::slotCreateFolder()
+{
+  bool ok;
+  QString folderName = KInputDialog::getText(i18n("Create New Folder"), i18n("Folder name:"), "", &ok, this);
+  if (ok)
+  {
+    KURL url = currentURL();
+    if (currentKFileTreeViewItem()->isDir())
+      url.setPath(url.path() + "/" + folderName + "/");
+    else
+      url.setPath(url.directory() + "/" + folderName +"/");
+    QuantaNetAccess::mkdir(url, this, -1);
+  }
+}
+
+void BaseTreeView::slotCreateFile()
+{
+  bool ok;
+  QString fileName = KInputDialog::getText(i18n("Create New File"), i18n("File name:"), "", &ok, this);
+  if (ok)
+  {
+    KURL url = currentURL();
+    if (currentKFileTreeViewItem()->isDir())
+      url.setPath(url.path() + "/" + fileName);
+    else
+      url.setPath(url.directory() + "/" + fileName);
+    if (QExtFileInfo::exists(url))
+    {
+      KMessageBox::error(this, i18n("<qt>Cannot create file, because a file named <b>%1</b> already exists.</qt>").arg(fileName), i18n("Error Creating File"));
+      return;
+    }
+    KTempFile *tempFile = new KTempFile(tmpDir);
+    tempFile->setAutoDelete(true);
+    tempFile->close();
+    if (QuantaNetAccess::copy(KURL::fromPathOrURL(tempFile->name()), url, this));
+    {
+      emit openFile(url);
+    }
+    delete tempFile;
+  }
+}
+
 #include "basetreeview.moc"
